EXEC [__AddStoredProcInfo]
	/* StoredProc_Name         */ 'DockerImages_GetImagesFromBlobDigest',
	/* Internal_Indicator      */ 'N',
	/* ReturnType_Name         */ 'DataTable',
	/* DataTableNames_Csv      */ 'DockerRepositoryTags_Extended',
	/* OutputPropertyNames_Csv */ NULL,
	/* Description_Text        */ 'Gets the images used by a Docker blob.'
GO

IF OBJECT_ID('[DockerImages_GetImagesFromBlobDigest]') IS NOT NULL DROP PROCEDURE [DockerImages_GetImagesFromBlobDigest]
GO

SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO

CREATE PROCEDURE [DockerImages_GetImagesFromBlobDigest]
(
	@Blob_Digest VARCHAR(128),
	@PublishedBefore_Date DATETIME = NULL,
	@DockerImages_Count INT = NULL
)
AS
BEGIN

SET NOCOUNT ON

	 IF @DockerImages_Count IS NOT NULL
		SET ROWCOUNT @DockerImages_Count

	SELECT DRT.[DockerRepository_Id]
		,DRT.[Tag_Name]
		,DRT.[DockerImage_Id]
		,DRT.[CreatedBy_User_Name]
		,DRT.[Created_Date]
		,DRT.[Comments_Text]
		,DRT.[Feed_Id]
		,DRT.[Repository_Name]
		,DRT.[Image_Digest]
		,DRT.[Cached_Indicator]
		,DRT.[Published_Date]
		,DRT.[Canonical_Tag_Name]
		,DRT.[Download_Count]
		,DRT.[DockerImage_Size]
		,DRT.[Vulnerabilities_Severity_Code]
		,DRT.[Vulnerabilities_Unassessed_Indicator]
		,DRT.[Vulnerabilities_Count]
		,DRT.[AssessedVulnerabilities_Count]
		,DRT.[Active_Indicator]
		,DRT.[AllowUnassessedVulnerabilities_Indicator]
		,DRT.[Feed_Description]
		,DRT.[Feed_Name]
		,DRT.[FeedType_Name]
	FROM [DockerRepositoryTags_Extended] DRT
			INNER JOIN [DockerImageLayers_Extended] DIL ON DRT.[DockerImage_Id] = DIL.[DockerImage_Id]
	WHERE DIL.[Blob_Digest] = @Blob_Digest
		AND (@PublishedBefore_Date IS NULL OR DRT.[Published_Date] < @PublishedBefore_Date)
	GROUP BY DRT.[DockerRepository_Id]
		,DRT.[Tag_Name]
		,DRT.[DockerImage_Id]
		,DRT.[CreatedBy_User_Name]
		,DRT.[Created_Date]
		,DRT.[Comments_Text]
		,DRT.[Feed_Id]
		,DRT.[Repository_Name]
		,DRT.[Image_Digest]
		,DRT.[Cached_Indicator]
		,DRT.[Published_Date]
		,DRT.[Canonical_Tag_Name]
		,DRT.[Download_Count]
		,DRT.[DockerImage_Size]
		,DRT.[Vulnerabilities_Severity_Code]
		,DRT.[Vulnerabilities_Unassessed_Indicator]
		,DRT.[Vulnerabilities_Count]
		,DRT.[AssessedVulnerabilities_Count]
		,DRT.[Active_Indicator]
		,DRT.[AllowUnassessedVulnerabilities_Indicator]
		,DRT.[Feed_Description]
		,DRT.[Feed_Name]
		,DRT.[FeedType_Name]

END
GO

GRANT EXECUTE ON [DockerImages_GetImagesFromBlobDigest] TO [ProGetUser_Role]
GO